@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11669 2019-07-31 11:16:05Z Trista $
+# $Id: __init__.py 980 2021-03-12 06:12:33Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2019-07-31 20:16:05 +0900 (週三, 31 七月 2019) $
-# $Revision: 11669 $
+# $Author: Lavender $ (last)
+# $Date: 2021-03-12 14:12:33 +0800 (週五, 12 三月 2021) $
+# $Revision: 980 $
 
 import os
 import sys
@@ -143,7 +143,6 @@ def run(self, command, notRecord=False, **kwargs):
 
     .. versionadded:: 2.0
     """
-    print("AAA", kwargs)
     if "hide" in kwargs and kwargs["hide"] == True:
         pass
     else:
